@@ -7,7 +7,7 @@ else
     MENU=menu-data-$(date +%Y%m%d).tar.gz
 fi
 
-UTILDIR=~/devel/gnome-app-install/checkout/main/util
+UTILDIR=utils/
 TOPDIR=./
 TARGETDIR=./menu-data/
 HERE=$PWD
